@@ -5,10 +5,12 @@ import matplotlib.pyplot as plt
 import pywt
 import scipy.signal
 from scipy import signal
-#from audio_proc_functions import *
+from Audio_proc_lib.audio_proc_functions import *
 from nsgt import NSGT, LogScale, LinScale, MelScale, OctScale
 #from constant_q_FB import create_filters
 import time
+import math
+import librosa
 
 
 def timeis(func):
@@ -295,167 +297,6 @@ def get_dft_mtx(signal_samples):
 
 
 
-def get_spectrogram_custom(x,nfft):
-
-    D = get_dft_mtx(nfft)
-
-    mod = len(x)%nfft
-    if mod :
-        x = x[:len(x)-mod]
-        #getting the segments of the signal (the columns contain the segments of nfft size )
-        S = np.reshape(x, (-1, nfft)).T
-    
-    X = np.matmul(D,S)
-
-    '''
-    librosa.stft(x , n_fft=4096)
-    librosa.display.specshow(librosa.amplitude_to_db(np.abs(X),ref=np.max), y_axis='log', sr=22050, 
-
-                         x_axis='time')
-    '''
-
-    return X,S
-
-
-#NAIVE IMPLEMENTATION OF GABOR TRANFORM (VIEWING THE PROCEDURE AS JUST CUTTING THE SIGNAL 
-# AND TAKING THE FFT INSTEAD OF A REDUNDUNT SYSTEM )   OFF COURSE IT DOESENT WORK FOR OTHER TYPES OF WINDOWS RATHER THAN RECT-------------------------------------------------------------
-def get_spectrogram_custom1(x,nfft,hop,win_type='Rectangular'):
-
-    D = get_dft_mtx(nfft)
-
-    w = create_desiered_window(win_type,nfft)
-
-    #OBTAINING THE SEGMENTS (ROWS OF S CONTAINS THE SEGMENTS)
-    S = []
-    for k in range(0,len(x)-nfft,hop):
-        S.append(w*x[k:k+nfft])
-    S = np.array(S)
-
-    #OBTAINING THE DFT OF EACH SEGMENT (EACH ROW OF X IS A SPECTRAL SLICE)
-    X = np.matmul(D,S.T).T
-
-    return X.T
-
-def get_inverse_stft(X,S1):
-
-    nfft = X.shape[0]
-    D = get_dft_mtx(nfft)
-
-    S = np.abs(np.matmul(np.conj(D).T,X)).T
-
-    s = np.reshape(S,np.prod(S.shape))
-
-    return s
-
-def get_inverse_stft1(X,hop):
-
-    nfft = X.shape[1]
-    D = get_dft_mtx(nfft)
-
-    X = X[0:X.shape[1]:nfft//hop,:]
-
-    #S = np.matmul(np.conj(D).T,X)
-    S = ifft(X)
-
-    #s = np.real(np.reshape(S.T,np.prod(S.shape)))
-    s = np.real(np.reshape(S,np.prod(S.shape)))
-
-    return s
-#----------------------------------------------------------------------------------------------------------------
-
-
-def gabor_analysis(x,g,a,M):
-
-    orig_len = len(x)
-    #x = SliceToPrevious(x)
-
-    N = len(x)//a
-    b = len(x)//M
-
-    g_pad = np.concatenate((g,np.zeros(len(x)-len(g))))
-    #center around zero
-    #g_pad = translation_operator(g_pad,len(g)//2)
-
-
-    #windowed_sig = x*translation_operator(g_pad,0)
-    windowed_sig = x*np.roll(g_pad,0)
-    #periodized_sig = ( periodization( windowed_sig , M )[:M])/np.sqrt(b)  
-    periodized_sig =  periodization_v2( windowed_sig , M )  
-    #periodized_sig = np.sqrt(1/M)*downsample(windowed_sig,b)
-    #periodized_sig = np.sqrt(1/M)*windowed_sig[0:len(x):b]
-    fourier_len_M = np.sqrt(1/M)*fft(periodized_sig)
-    #fourier_len_M = fft(windowed_sig,M)
-    X = fourier_len_M[: , np.newaxis]
-
-    for n in range(1,N):
-        windowed_sig = x*np.roll(g_pad,n*a)
-        #periodized_sig = ( periodization( windowed_sig , M )[:M])/np.sqrt(b)  
-        periodized_sig =  periodization_v2( windowed_sig , M )    
-        #periodized_sig = np.sqrt(1/M)*downsample(windowed_sig,b)
-        #periodized_sig = np.sqrt(1/M)*windowed_sig[0:len(x):b]
-        fourier_len_M = fft(periodized_sig)
-        #fourier_len_M = fft(windowed_sig,M)
-        X = np.concatenate((X,fourier_len_M[: , np.newaxis]),axis=1)
-
-    return X
-
-@timeis
-def gabor_analysis_faster(x,g,a,M):
-
-    orig_len = len(x)
-    #x = SliceToPrevious(x)
-
-    N = len(x)//a
-    b = len(x)//M
-
-    X = []
-
-
-    g_sq = g**2
-    x = np.concatenate((x,np.zeros(a)))
-    frame_operator = np.zeros(len(x))
-
-
-    # periodized_sig = x[:len(g)]*g 
-    # frame_operator[:len(g)] = g_sq
-
-
-    # fourier_len_M = fft(periodized_sig)
-    # X.append(fourier_len_M)
-
-
-    for n in range(N):
-
-        #windowed_sig = np.concatenate( (x[n*a:n*a+len(g)]*g , np.zeros(len(x)-len(g))) )   
-        periodized_sig = x[n*a:n*a+len(g)]*g    
-
-        frame_operator[n*a:n*a+len(g)]+=g_sq 
-
-        #periodized_sig =  periodization_v2( windowed_sig , M )    
-
-        fourier_len_M = fft(periodized_sig)
-        X.append(fourier_len_M)
-
-        #X = np.concatenate((X,fourier_len_M[: , np.newaxis]),axis=1)
-
-    return np.array(X).T , M*frame_operator
-
-@timeis
-def gabor_synthesis_faster(X,g,a,M,frame_operator):
-    
-    N = X.shape[1]
-    L = a*N
-    # f0 = (np.real(ifft(X[:,0])))*(g/frame_operator[:len(g)])  
-    # f_rec = np.zeros(L)
-    # f_rec[:len(g)] = f0  
-
-    f_rec = np.zeros(L)
-    for n in range(N):
-
-        fn = (np.real(ifft(X[:,n])))*(g/frame_operator[n*a:n*a+len(g)])  
-        f_rec[n*a:n*a+len(g)] = f_rec[n*a:n*a+len(g)] + fn  
-
-    return f_rec
 
 
 
@@ -614,6 +455,7 @@ h = [1,1]/np.sqrt(2)
 g = [1,-1]/np.sqrt(2)
 
 def Harr_analysis(x,h,g):
+    
     aprox_coefs = LTI_filtering(h,x)[::2]
     det_coefs = LTI_filtering(g,x)[::2]
 
